==> chaosmesh-model-5.2.0-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/JVMDelaySpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.Integer;
import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface JVMDelaySpecFluent<A extends JVMDelaySpecFluent<A>> extends Fluent<A> {


    public Boolean isAfter();
    public A withAfter(Boolean after);
    public Boolean hasAfter();
    public A withNewAfter(String arg1);
    public A withNewAfter(boolean arg1);
    public String getClassname();
    public A withClassname(String classname);
    public Boolean hasClassname();
    public A withNewClassname(String arg1);
    public A withNewClassname(StringBuilder arg1);
    public A withNewClassname(StringBuffer arg1);
    public String getMethodname();
    public A withMethodname(String methodname);
    public Boolean hasMethodname();
    public A withNewMethodname(String arg1);
    public A withNewMethodname(StringBuilder arg1);
    public A withNewMethodname(StringBuffer arg1);
    public Integer getOffset();
    public A withOffset(Integer offset);
    public Boolean hasOffset();
    public A withNewOffset(String arg1);
    public A withNewOffset(int arg1);
    public Integer getTime();
    public A withTime(Integer time);
    public Boolean hasTime();
    public A withNewTime(String arg1);
    public A withNewTime(int arg1);
}

==> chaosmesh-model-5.3.0-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/JVMDelaySpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.Integer;
import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface JVMDelaySpecFluent<A extends JVMDelaySpecFluent<A>> extends Fluent<A> {


    public Boolean getAfter();
    public A withAfter(Boolean after);
    public Boolean hasAfter();
    public A withNewAfter(String arg1);
    public A withNewAfter(boolean arg1);
    public String getClassname();
    public A withClassname(String classname);
    public Boolean hasClassname();
    public A withNewClassname(StringBuilder arg1);
    public A withNewClassname(int[] arg1,int arg2,int arg3);
    public A withNewClassname(char[] arg1);
    public A withNewClassname(StringBuffer arg1);
    public A withNewClassname(byte[] arg1,int arg2);
    public A withNewClassname(byte[] arg1);
    public A withNewClassname(char[] arg1,int arg2,int arg3);
    public A withNewClassname(byte[] arg1,int arg2,int arg3);
    public A withNewClassname(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewClassname(String arg1);
    public String getMethodname();
    public A withMethodname(String methodname);
    public Boolean hasMethodname();
    public A withNewMethodname(StringBuilder arg1);
    public A withNewMethodname(int[] arg1,int arg2,int arg3);
    public A withNewMethodname(char[] arg1);
    public A withNewMethodname(StringBuffer arg1);
    public A withNewMethodname(byte[] arg1,int arg2);
    public A withNewMethodname(byte[] arg1);
    public A withNewMethodname(char[] arg1,int arg2,int arg3);
    public A withNewMethodname(byte[] arg1,int arg2,int arg3);
    public A withNewMethodname(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewMethodname(String arg1);
    public Integer getOffset();
    public A withOffset(Integer offset);
    public Boolean hasOffset();
    public A withNewOffset(int arg1);
    public Integer getTime();
    public A withTime(Integer time);
    public Boolean hasTime();
    public A withNewTime(int arg1);
}
